@@ -64,12 +64,12 @@
 
 /** Some MPI implementations do not allow passing MPI_DATATYPE_NULL to
  * comm functions even though the send or recv length is 0, in these
- * cases we use MPI_CHAR */
-#if defined(MPT_VERSION) || defined(OPEN_MPI)
+ * cases we use MPI_CHAR, after this issue raised its ugly head again in mpich
+ * 4.0.0 we decided to use this workaround in all cases.  
+ * See https://github.com/NCAR/ParallelIO/issues/1945 */
+
 #define PIO_DATATYPE_NULL MPI_CHAR
-#else
-#define PIO_DATATYPE_NULL MPI_DATATYPE_NULL
-#endif
+
 
 #if PIO_ENABLE_LOGGING
 void pio_log(int severity, const char *fmt, ...);
